==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla neteisinga",
    "Unknown error" : "Neatpažinta klaida",
    "All files" : "Visi failai",
    "Saved" : "Išsaugoti",
    "There was an error saving" : "Įvyko klaida rašant",
    "File could not be found" : "Nepavyko rasti failo",
    "Home" : "Namų",
    "Close" : "Užverti",
    "Favorites" : "Mėgstamiausi",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "Upload cancelled." : "Įkėlimas atšauktas.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai katalogas arba yra 0 baitų dydžio",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Keliate {size1}, bet tik {size2} yra likę",
    "Target folder \"{dir}\" does not exist any more" : "Nurodytas aplankas \"{dir}\" nebeegzistuoja",
    "Target folder does not exist any more" : "Nurodytas aplankas nebeegzistuoja",
    "Not enough free space" : "Nepakanka vietos",
    "Uploading..." : "Įkeliama...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Failo įkėlimas pradėtas. Jei paliksite šį puslapį, įkėlimas nutrūks.",
    "Actions" : "Veiksmai",
    "Download" : "Atsisiųsti",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Disconnect storage" : "Atjungti saugyklą",
    "Unshare" : "Nebesidalinti",
    "Could not load info for file \"{file}\"" : "Nepavyko gauti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Informacija",
    "Select" : "Pasirinkiti",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "Invalid path" : "Netinkamas kelias",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Katalogas nepasiekiamas, prašome peržiūrėti žurnalo įrašus arba susisiekti su administratoriumi",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "{newName} already exists" : "{newName} jau egzistuoja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo \"{fileName}\", nes jis jau nebeegzistuoja",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Prašome pasirinkti kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\" - failas su tokiu pavadinimu jau egzistuoja",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\"- aplankas su tokiu pavadinimu jau egzistuoja",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų"],
    "New" : "Naujas",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas failo pavadinime.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų visa vieta serveryje užimta",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų vieta serveryje beveik visa užimta ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitikmuo „{filter}“","atitikmenys „{filter}“","atitikmenų „{filter}“"],
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų"],
    "Favorited" : "Pažymėta mėgstamu",
    "Favorite" : "Mėgiamas",
    "Folder" : "Katalogas",
    "New folder" : "Naujas aplankas",
    "{newname} already exists" : "{newname} jau egzistuoja",
    "Upload" : "Įkelti",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "A new file or folder has been <strong>created</strong>" : "Naujas failas ar aplankas buvo <strong>sukurtas</strong>",
    "A file or folder has been <strong>changed</strong>" : "Failas ar aplankas buvo <strong>pakeistas</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie sukūrimą ir pokyčius jūsų <strong>mėgiamuose failuose</strong> <em>(Tik srautas)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Failas ar aplankas buvo <strong>ištrintas</strong>",
    "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas buvo <strong>atkurtas</strong>",
    "You created %1$s" : "Jūs sukūrėte %1$s",
    "%2$s created %1$s" : "%2$s sukūrė %1$s",
    "%1$s was created in a public folder" : "%1$s buvo sukurta viešajame aplanke",
    "You changed %1$s" : "Jūs pakeitėte %1$s",
    "%2$s changed %1$s" : "%2$s pakeitė %1$s",
    "You deleted %1$s" : "Jūs ištrynėte %1$s",
    "%2$s deleted %1$s" : "%2$s ištrynė %1$s",
    "You restored %1$s" : "Jūs atkūrėte %1$s",
    "%2$s restored %1$s" : "%2$s atkurta %1$s",
    "Changed by %2$s" : "Pakeitė %2$s",
    "Deleted by %2$s" : "Ištrynė %2$s",
    "Restored by %2$s" : "Atkūrė %2$s",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "File handling" : "Failų tvarkymas",
    "Maximum upload size" : "Maksimalus įkeliamo failo dydis",
    "max. possible: " : "maks. galima:",
    "Save" : "Išsaugoti",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Su PHP-FPM atnaujinimai gali užtrukti apie 5min.",
    "Missing permissions to edit from here." : "Draudžiama iš čia redaguoti",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "No files in here" : "Čia nėra failų",
    "Upload some content or sync with your devices!" : "Įkelkite kokį nors turinį, arba sinchronizuokite su savo įrenginiais!",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, kuris leidžiamas šiame serveryje",
    "No favorites" : "Nėra mėgstamiausių",
    "Files and folders you mark as favorite will show up here" : "Failai ir aplankai, kuriuos pažymite mėgstamais, atsiras čia",
    "Text file" : "Teksto failas",
    "New text file.txt" : "Naujas tekstas file.txt",
    "Unknown user" : "Neatpažintas naudotojas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla neteisinga",
    "Unknown error" : "Neatpažinta klaida",
    "All files" : "Visi failai",
    "File could not be found" : "Nepavyko rasti failo",
    "Home" : "Namų",
    "Close" : "Užverti",
    "Favorites" : "Mėgstamiausi",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "Upload cancelled." : "Įkėlimas atšauktas.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai katalogas arba yra 0 baitų dydžio",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Keliate {size1}, bet tik {size2} yra likę",
    "Target folder \"{dir}\" does not exist any more" : "Nurodytas aplankas \"{dir}\" nebeegzistuoja",
    "Target folder does not exist any more" : "Nurodytas aplankas nebeegzistuoja",
    "Not enough free space" : "Nepakanka vietos",
    "Uploading..." : "Įkeliama...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Failo įkėlimas pradėtas. Jei paliksite šį puslapį, įkėlimas nutrūks.",
    "Actions" : "Veiksmai",
    "Download" : "Atsisiųsti",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Disconnect storage" : "Atjungti saugyklą",
    "Unshare" : "Nebesidalinti",
    "Could not load info for file \"{file}\"" : "Nepavyko gauti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Informacija",
    "Select" : "Pasirinkiti",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "Invalid path" : "Netinkamas kelias",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Katalogas nepasiekiamas, prašome peržiūrėti žurnalo įrašus arba susisiekti su administratoriumi",
    "group" : "grupė",
    "Remote share" : "Nutolęs dalinimasis",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "{newName} already exists" : "{newName} jau egzistuoja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo \"{fileName}\", nes jis jau nebeegzistuoja",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Prašome pasirinkti kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\" - failas su tokiu pavadinimu jau egzistuoja",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\"- aplankas su tokiu pavadinimu jau egzistuoja",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankų"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failų"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliama %n failų"],
    "New" : "Naujas",
    "Unknown user" : "Neatpažintas naudotojas",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas failo pavadinime.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų visa vieta serveryje užimta",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų vieta serveryje beveik visa užimta ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitikmuo „{filter}“","atitikmenys „{filter}“","atitikmenų „{filter}“","atitikmenų „{filter}“"],
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Pažymėta mėgstamu",
    "Favorite" : "Mėgiamas",
    "Folder" : "Katalogas",
    "New folder" : "Naujas aplankas",
    "{newname} already exists" : "{newname} jau egzistuoja",
    "Upload" : "Įkelti",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "A new file or folder has been <strong>created</strong>" : "Naujas failas ar aplankas buvo <strong>sukurtas</strong>",
    "A file or folder has been <strong>changed</strong>" : "Failas ar aplankas buvo <strong>pakeistas</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie sukūrimą ir pokyčius jūsų <strong>mėgiamuose failuose</strong> <em>(Tik srautas)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Failas ar aplankas buvo <strong>ištrintas</strong>",
    "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas buvo <strong>atkurtas</strong>",
    "You created %1$s" : "Jūs sukūrėte %1$s",
    "%2$s created %1$s" : "%2$s sukūrė %1$s",
    "%1$s was created in a public folder" : "%1$s buvo sukurta viešajame aplanke",
    "You changed %1$s" : "Jūs pakeitėte %1$s",
    "%2$s changed %1$s" : "%2$s pakeitė %1$s",
    "You deleted %1$s" : "Jūs ištrynėte %1$s",
    "%2$s deleted %1$s" : "%2$s ištrynė %1$s",
    "You restored %1$s" : "Jūs atkūrėte %1$s",
    "%2$s restored %1$s" : "%2$s atkurta %1$s",
    "Changed by %2$s" : "Pakeitė %2$s",
    "Deleted by %2$s" : "Ištrynė %2$s",
    "Restored by %2$s" : "Atkūrė %2$s",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "No files in here" : "Čia nėra failų",
    "Upload some content or sync with your devices!" : "Įkelkite kokį nors turinį, arba sinchronizuokite su savo įrenginiais!",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, kuris leidžiamas šiame serveryje",
    "No favorites" : "Nėra mėgstamiausių",
    "Files and folders you mark as favorite will show up here" : "Failai ir aplankai, kuriuos pažymite mėgstamais, atsiras čia",
    "Text file" : "Teksto failas",
    "New text file.txt" : "Naujas tekstas file.txt"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
